package main

import (
	"epochsilicon/pkg/service"
	"epochsilicon/pkg/ui"
	"epochsilicon/pkg/utils"
	"fyne.io/fyne/v2"
	"fyne.io/fyne/v2/app"
	"github.com/rs/zerolog"
	"github.com/rs/zerolog/log"
	"strings"
)

const appVersion = "1.0.0"

func init() {
	zerolog.TimeFieldFormat = zerolog.TimeFormatUnix
}

func main() {
	PEApp := app.NewWithID("com.burkey.epochsilicon")
	PEWindow := PEApp.NewWindow("EpochSilicon v" + appVersion)
	PEWindow.Resize(fyne.NewSize(650, 500))
	PEWindow.SetFixedSize(true)

	go func() {
		prefs, _ := utils.LoadPrefs()
		updateInfo, updateAvailable, err := utils.CheckForUpdateWithAssets(appVersion)
		if err != nil {
			log.Debug().Msgf("Failed to check for updates: %v", err)
			return
		}

		if !updateAvailable {
			log.Debug().Msgf("No updates available")
			return
		}

		latestVersion := strings.TrimPrefix(updateInfo.TagName, "v")
		log.Debug().Msgf("Update available: current=%s, latest=%s", appVersion, latestVersion)

		// Skip if user has suppressed this version
		if prefs.SuppressedUpdateVersion == latestVersion {
			log.Debug().Msgf("Update suppressed by user: %s", latestVersion)
			return
		}

		// Show enhanced update dialog
		ui.ShowUpdateDialog(updateInfo, appVersion, PEWindow)
	}()

	content := ui.CreateUI(PEWindow)
	PEWindow.SetContent(content)

	// Set up cleanup when window closes
	PEWindow.SetCloseIntercept(func() {
		log.Debug().Msg("Application closing, cleaning up RosettaX87 service...")
		service.CleanupService()
		PEApp.Quit()
	})

	PEWindow.ShowAndRun()
}
